@@ -624,7 +624,7 @@ var NagVisStatefulObject = NagVisObject.extend({
         // 1 contains the color to be used
         for(var i = 0; i < ranges.length; i++) {
             var parts = ranges[i].split(':');
-            if(parseInt(perc) <= parts[0])
+            if(parseFloat(perc) <= parts[0])
                 return parts[1];
             parts = null;
         }
@@ -715,7 +715,7 @@ var NagVisStatefulObject = NagVisObject.extend({
             return set;
 
         // Calculate percentages with 2 decimals and reset other options
-        return Array(set[0], Math.round((set[1]*100/set[6]*100)/100), '%', set[3], set[4], 0, 100);
+        return Array(set[0], Math.round(set[1]*100/set[6]*100)/100, '%', set[3], set[4], 0, 100);
     },
 
     /**
@@ -826,8 +826,8 @@ var NagVisStatefulObject = NagVisObject.extend({
 
         var jsObj = getMapObjByDomObjId(objId);
 
-        jsObj.conf.label_x = jsObj.calcNewLabelCoord(jsObj.conf.label_x, jsObj.conf.x, obj.x);
-        jsObj.conf.label_y = jsObj.calcNewLabelCoord(jsObj.conf.label_y, jsObj.conf.y, obj.y);
+        jsObj.conf.label_x = jsObj.calcNewLabelCoord(jsObj.conf.label_x, jsObj.parseCoord(jsObj.conf.x, 'x'), obj.x);
+        jsObj.conf.label_y = jsObj.calcNewLabelCoord(jsObj.conf.label_y, jsObj.parseCoord(jsObj.conf.y, 'y'), obj.y);
 
         jsObj      = null;
         objId      = null;
