@@ -203,10 +203,11 @@ $mapConfigVars = Array(
     ),
 
     'context_menu' => Array(
-        'must' => 0,
-        'default' => cfg('defaults', 'contextmenu'),
-        'match' => MATCH_BOOLEAN,
-        'field_type' => 'boolean'),
+        'must'       => 0,
+        'default'    => cfg('defaults', 'contextmenu'),
+        'match'      => MATCH_BOOLEAN,
+        'field_type' => 'boolean',
+    ),
     'context_template' => Array(
         'must'          => 0,
         'default'       => cfg('defaults', 'contexttemplate'),
@@ -487,10 +488,10 @@ $mapConfigVars = Array(
         'depends_on' => 'view_type',
         'depends_value' => 'line'),
     'line_weather_colors' => Array(
-        'must' => 0,
-        'default' => '10:#8c00ff,25:#2020ff,40:#00c0ff,55:#00f000,70:#f0f000,85:#ffc000,100:#ff0000',
-        'match' => MATCH_WEATHER_COLORS,
-        'depends_on' => 'view_type',
+        'must'          => 0,
+        'default'       => cfg('defaults', 'line_weather_colors'),
+        'match'         => MATCH_WEATHER_COLORS,
+        'depends_on'    => 'view_type',
         'depends_value' => 'line'),
 
     'in_maintenance' => Array(
@@ -799,6 +800,12 @@ $mapConfigVars = Array(
     ),
 );
 
+// STATELESS LINE SPECIFIC OPTIONS
+$mapConfigVars['context_menu_line'] = $mapConfigVars['context_menu'];
+$mapConfigVars['context_menu_line']['default'] = '0';
+$mapConfigVars['hover_menu_line'] = $mapConfigVars['hover_menu'];
+$mapConfigVars['hover_menu_line']['default'] = '0';
+
 //
 // map configuration variable registration
 //
@@ -1096,9 +1103,9 @@ $mapConfigVarMap['line'] = Array(
     'line_width' => null,
     'line_color' => null,
     'line_color_border' => null,
-    'context_menu' => null,
+    'context_menu_line' => 'context_menu',
     'context_template' => null,
-    'hover_menu' => null,
+    'hover_menu_line' => 'hover_menu',
     'hover_template' => null,
     'hover_url' => null,
     'hover_delay' => null,
